@@ -4,6 +4,7 @@
 
 #include "portalwaylandcontext.h"
 #include "screenshotportal.h"
+#include "screencastportal.h"
 
 #include <QGuiApplication>
 #include <qpa/qplatformintegration.h>
@@ -17,6 +18,8 @@ PortalWaylandContext::PortalWaylandContext(QObject *parent)
     : QObject(parent)
     , QDBusContext()
     , m_screenCopyManager(new ScreenCopyManager(this))
+    , m_treelandCaptureManager(new TreeLandCaptureManager(this))
 {
     auto screenShotPortal = new ScreenshotPortalWayland(this);
+    auto screencastPortal = new ScreencastPortalWayland(this);
 }
