@@ -4,6 +4,8 @@
 
 #include "ddesktopportal.h"
 #include "wayland/portalwaylandcontext.h"
+#include "wayland/toplevelmodel.h"
+#include "wayland/restoredata.h"
 
 #include <QApplication>
 #include <QDBusConnection>
@@ -11,6 +13,7 @@
 #include <QLoggingCategory>
 #include <QTranslator>
 #include <QStandardPaths>
+#include <QDBusMetaType>
 
 Q_LOGGING_CATEGORY(XdgDesktopDDE, "xdg-dde")
 
@@ -21,6 +24,11 @@ inline static bool onWayland()
 
 int main(int argc, char *argv[])
 {
+    // qputenv("PIPEWIRE_DEBUG", "4");
+    // qputenv("QT_LOGGING_RULES", "dde.portal.ScreenCast*.debug=true");
+    // qputenv("WAYLAND_DEBUG", "1");
+    qDBusRegisterMetaType<RestoreData>();
+    qDBusRegisterMetaType<QStringMap>();
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     /* Disable X11 session management
     As XdgDesktopPortal is a QGuiApplication it connects to our X session manager.
@@ -39,7 +47,9 @@ int main(int argc, char *argv[])
     QString languagePath = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
                                                   QString("xdg-desktop-portal-dde/translations"),
                                                   QStandardPaths::LocateDirectory);
-    translator.load(languagePath+"/xdg-desktop-portal-dde_" + QLocale::system().name());
+    if (!translator.load(languagePath+"/xdg-desktop-portal-dde_" + QLocale::system().name())) {
+        qCWarning(XdgDesktopDDE) << "Failed to load translation file for locale:" << QLocale::system().name();
+    }
     a.installTranslator(&translator);
 
     QDBusConnection sessionBus = QDBusConnection::sessionBus();
